#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1
key:                  lsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  682140cb75d1e6bfb20c56455d2ed201
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-1mpQUBvmFx35ELIFe2gyvF:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-1mpQUBvmFx35ELIFe2gyvF:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-1mpQUBvmFx35ELIFe2gyvF:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-1mpQUBvmFx35ELIFe2gyvF:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1
depends:
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    async-2.2.6-BOzBj9OU2RsBdXVaxuDTSw
    attoparsec-0.14.4-qc2ScMijHsIVylJ0k0iua base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.7-6hxtiPpWRzu5HeANWfFp34
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    lens-aeson-1.2.3-3DLc89EhcgMIWsG7tCrhaz
    lsp-types-2.0.2.0-1mpQUBvmFx35ELIFe2gyvF mtl-2.3.1
    prettyprinter-1.7.2-CIJHFVXNQ7ULgjXbroiIfc
    random-1.2.1.3-JQ5HMleih0QHEX58PgSIMQ
    row-types-1.0.1.2-1ARAb8lCwbsG34C3ABHuJO
    sorted-list-0.2.3.1-1wowz2HmVybCm1YORClO58 stm-2.5.1.0
    temporary-1.3-1ezn4dc6wi13jwuWHEP4w4 text-2.0.2
    text-rope-0.3-EGYQdR2gSK4IsR7LLld6Sh transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    uuid-1.3.16.1-7PYZMZ1xYXRJIRW62n80Y6

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

